@@ -1,6 +1,7 @@
 ///
 ///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///            (C) 2008-2009 Ziga Lenarcic <zigalenarcic@users.sourceforge.net>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -38,11 +39,13 @@ const int langs[] =
   {
     wxLANGUAGE_DEFAULT,
     wxLANGUAGE_CATALAN,
+    wxLANGUAGE_CHINESE_SIMPLIFIED,
     wxLANGUAGE_CHINESE_TRADITIONAL,
     wxLANGUAGE_CZECH,
     wxLANGUAGE_DANISH,
     wxLANGUAGE_ENGLISH,
     wxLANGUAGE_FRENCH,
+    wxLANGUAGE_GALICIAN,
     wxLANGUAGE_GERMAN,
     wxLANGUAGE_GREEK,
     wxLANGUAGE_HUNGARIAN,
@@ -55,7 +58,7 @@ const int langs[] =
     wxLANGUAGE_UKRAINIAN
   };
 
-#define LANGUAGE_NUMBER 17
+#define LANGUAGE_NUMBER 18
 
 
 Config::Config(wxWindow* parent)
@@ -137,6 +140,7 @@ void Config::SetProperties()
   bool match = true, showLongExpr = false, savePanes = false;
   bool fixedFontTC = true, changeAsterisk = false, usejsmath = true, keepPercent = true;
   bool enterEvaluates = false, saveUntitled = true, openHCaret = false;
+  bool insertAns = true;
   int rs = 0;
   int lang = wxLANGUAGE_UNKNOWN;
   int panelSize = 1;
@@ -154,6 +158,7 @@ void Config::SetProperties()
   config->Read(wxT("enterEvaluates"), &enterEvaluates);
   config->Read(wxT("saveUntitled"), &saveUntitled);
   config->Read(wxT("openHCaret"), &openHCaret);
+  config->Read(wxT("insertAns"), &insertAns);
   config->Read(wxT("usejsmath"), &usejsmath);
   config->Read(wxT("keepPercent"), &keepPercent);
 
@@ -206,6 +211,7 @@ void Config::SetProperties()
   m_enterEvaluates->SetValue(enterEvaluates);
   m_saveUntitled->SetValue(saveUntitled);
   m_openHCaret->SetValue(openHCaret);
+  m_insertAns->SetValue(insertAns);
   m_fixedFontInTC->SetValue(fixedFontTC);
   m_useJSMath->SetValue(usejsmath);
   m_keepPercentWithSpecials->SetValue(keepPercent);
@@ -227,7 +233,7 @@ wxPanel* Config::CreateOptionsPanel()
   wxPanel *panel = new wxPanel(m_notebook, -1);
 
   wxFlexGridSizer* grid_sizer = new wxFlexGridSizer(2, 2, 5, 5);
-  wxFlexGridSizer* vsizer = new wxFlexGridSizer(11,1,5,5);
+  wxFlexGridSizer* vsizer = new wxFlexGridSizer(12,1,5,5);
 
   int defaultPort = 4010;
   wxConfig::Get()->Read(wxT("defaultPort"), &defaultPort);
@@ -237,11 +243,13 @@ wxPanel* Config::CreateOptionsPanel()
     {
       _("(Use default language)"),
       _("Catalan"),
+      _("Chinese Simplified"),
       _("Chinese traditional"),
       _("Czech"),
       _("Danish"),
       _("English"),
       _("French"),
+      _("Galician"),
       _("German"),
       _("Greek"),
       _("Hungarian"),
@@ -267,6 +275,7 @@ wxPanel* Config::CreateOptionsPanel()
   m_enterEvaluates = new wxCheckBox(panel, -1, _("Enter evaluates cells"));
   m_saveUntitled = new wxCheckBox(panel, -1, _("Ask to save untitled documents"));
   m_openHCaret = new wxCheckBox(panel, -1, _("Open a cell when Maxima expects input"));
+  m_insertAns = new wxCheckBox(panel, -1, _("Insert % before an operator at the beginning of a cell"));
 
   // TAB 1
   // Maxima options box
@@ -287,6 +296,7 @@ wxPanel* Config::CreateOptionsPanel()
   vsizer->Add(m_enterEvaluates, 0, wxALL, 5);
   vsizer->Add(m_saveUntitled, 0, wxALL, 5);
   vsizer->Add(m_openHCaret, 0, wxALL, 5);
+  vsizer->Add(m_insertAns, 0, wxALL, 5);
 
   vsizer->AddGrowableRow(10);
   panel->SetSizer(vsizer);
@@ -332,8 +342,6 @@ wxPanel* Config::CreateStylePanel()
 
   wxFlexGridSizer* vsizer = new wxFlexGridSizer(3,1,5,5);
   wxFlexGridSizer* grid_sizer_1 = new wxFlexGridSizer(3, 2, 2, 2);
-  wxFlexGridSizer* grid_sizer_2 = new wxFlexGridSizer(5, 1, 3, 3);
-  wxFlexGridSizer* grid_sizer_3 = new wxFlexGridSizer(4, 1, 2, 7);
   wxStaticBoxSizer* sb_sizer_1 = new wxStaticBoxSizer(fonts, wxVERTICAL);
   wxStaticBoxSizer* sb_sizer_2 = new wxStaticBoxSizer(styles, wxVERTICAL);
   wxBoxSizer* hbox_sizer_1 = new wxBoxSizer(wxHORIZONTAL);
@@ -447,6 +455,7 @@ void Config::WriteSettings()
   config->Write(wxT("enterEvaluates"), m_enterEvaluates->GetValue());
   config->Write(wxT("saveUntitled"), m_saveUntitled->GetValue());
   config->Write(wxT("openHCaret"), m_openHCaret->GetValue());
+  config->Write(wxT("insertAns"), m_insertAns->GetValue());
   config->Write(wxT("defaultPort"), m_defaultPort->GetValue());
   config->Write(wxT("AUI/savePanes"), m_savePanes->GetValue());
   config->Write(wxT("usejsmath"), m_useJSMath->GetValue());
