@@ -1,5 +1,6 @@
 ///
 ///  Copyright (C) 2006-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -37,6 +38,7 @@ EditorCell::EditorCell() : MathCell()
   m_isActive = false;
   m_matchParens = true;
   m_paren1 = m_paren2 = -1;
+  m_insertAns = true;
   m_isDirty = false;
   m_hasFocus = false;
   m_underlined = false;
@@ -903,7 +905,7 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
     }
 
     // if we have a selection either put parens around it (and don't write the letter afterwards)
-    // od delete selection and write letter (insertLetter = true).
+    // or delete selection and write letter (insertLetter = true).
     if (m_selectionStart > -1) {
       SaveValue();
       long start = MIN(m_selectionEnd, m_selectionStart);
@@ -1021,6 +1023,22 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
             m_text = m_text.SubString(0, m_positionOfCaret - 2) +
                        m_text.SubString(m_positionOfCaret, m_text.Length());
           break;
+        case '+':
+        // case '-': // this could mean negative.
+        case '*':
+        case '/':
+        case '^':
+        case '=':
+        case ',':
+          wxChar key = event.GetKeyCode();
+          size_t len = m_text.Length();
+          if (m_insertAns && len == 1 && m_positionOfCaret == 1)
+          {
+            m_text = m_text.SubString(0, m_positionOfCaret - 2) + wxT("%") +
+                     m_text.SubString(m_positionOfCaret - 1, m_text.Length());
+            m_positionOfCaret += 1;
+          }
+          break;
         }
       }
     } // end if (insertLetter)
@@ -1036,8 +1054,71 @@ void EditorCell::ProcessEvent(wxKeyEvent &event)
   m_displayCaret = true;
 }
 
+/**
+ * For a given quotation mark ("), find a matching quote.
+ * Since there are no nested quotes, an odd-numbered, non-escaped quote
+ * is an opening quote, and an even-numbered non-escaped quote
+ * is a closing quote.
+ *
+ * @return true if matching quotation marks were found; false otherwise
+ */
+bool EditorCell::FindMatchingQuotes()
+{
+  int pos = m_positionOfCaret;
+  if (pos < 0)
+  {
+    m_paren1 = m_paren2 = -1;
+    return false;
+  }
+
+  if (pos == m_text.Length() ||
+      wxString(wxT("\"")).Find(m_text.GetChar(pos)) == -1)
+  {
+    pos--;
+    if (pos < 0 ||
+        wxString(wxT("\"")).Find(m_text.GetChar(pos)) == -1)
+    {
+      m_paren1 = m_paren2 = -1;
+      return false;
+    }
+  }
+
+  int count = 0;
+  for (int i = 0; i < (int) m_text.Length(); ++i)
+  {
+    if (m_text.GetChar(i) == '"' &&
+        ((i == 0) ||
+         (i >= 1 && m_text.GetChar(i-1) != '\\')))
+    {
+      ++count;
+      if (count&1)
+      {
+        m_paren1 = i;  // open quote here
+      }
+      else
+      {
+        m_paren2 = i;  // close quote here
+        if (m_paren1 == pos || m_paren2 == pos)
+        {
+          // found the pair of quotes under the cursor
+          return true;
+        }
+      }
+    }
+  }
+
+  // didn't find matching quotes; do not highlight quotes
+  m_paren1 = m_paren2 = -1;
+  return false;
+}
+
 void EditorCell::FindMatchingParens()
 {
+  if (FindMatchingQuotes())
+  {
+    return;
+  }
+
   m_paren2 = m_positionOfCaret;
   if (m_paren2 < 0)
   {
@@ -1574,7 +1655,6 @@ bool EditorCell::CopyToClipboard()
     return false;
   if (wxTheClipboard->Open())
   {
-    wxTheClipboard->UsePrimarySelection(false);
     long start = MIN(m_selectionStart, m_selectionEnd);
     long end = MAX(m_selectionStart, m_selectionEnd) - 1;
     wxString s = m_text.SubString(start, end);
@@ -1635,9 +1715,10 @@ void EditorCell::InsertText(wxString text)
 
 void EditorCell::PasteFromClipboard(bool primary)
 {
+  if (primary)
+    wxTheClipboard->UsePrimarySelection(true);
   if (wxTheClipboard->Open())
   {
-    wxTheClipboard->UsePrimarySelection(primary);
     if (wxTheClipboard->IsSupported(wxDF_TEXT))
     {
       wxTextDataObject obj;
@@ -1646,6 +1727,8 @@ void EditorCell::PasteFromClipboard(bool primary)
     }
     wxTheClipboard->Close();
   }
+  if (primary)
+    wxTheClipboard->UsePrimarySelection(false);
 }
 
 wxString EditorCell::GetLineString(int line, int start, int end)
@@ -1760,28 +1843,49 @@ void EditorCell::ClearUndo()
 
 void EditorCell::SetValue(wxString text)
 {
-  if (m_type == MC_TYPE_INPUT && m_matchParens)
+  if (m_type == MC_TYPE_INPUT)
   {
-    if (text == wxT("(")) {
-      m_text = wxT("()");
-      m_positionOfCaret = 1;
-    }
-    else if (text == wxT("[")) {
-      m_text = wxT("[]");
-      m_positionOfCaret = 1;
-    }
-    else if (text == wxT("{")) {
-      m_text = wxT("{}");
-      m_positionOfCaret = 1;
-    }
-    else if (text == wxT("\"")) {
-      m_text = wxT("\"\"");
-      m_positionOfCaret = 1;
+    if (m_matchParens)
+    {
+      if (text == wxT("(")) {
+        m_text = wxT("()");
+        m_positionOfCaret = 1;
+      }
+      else if (text == wxT("[")) {
+        m_text = wxT("[]");
+        m_positionOfCaret = 1;
+      }
+      else if (text == wxT("{")) {
+        m_text = wxT("{}");
+        m_positionOfCaret = 1;
+      }
+      else if (text == wxT("\"")) {
+        m_text = wxT("\"\"");
+        m_positionOfCaret = 1;
+      }
+      else {
+        m_text = text;
+        m_positionOfCaret = m_text.Length();
+      }
     }
     else {
       m_text = text;
       m_positionOfCaret = m_text.Length();
     }
+
+    if (m_insertAns)
+    {
+      if (m_text == wxT("+") ||
+          m_text == wxT("*") ||
+          m_text == wxT("/") ||
+          m_text == wxT("^") ||
+          m_text == wxT("=") ||
+          m_text == wxT(","))
+      {
+        m_text = wxT("%") + m_text;
+        m_positionOfCaret = m_text.Length();
+      }
+    }
   }
   else
   {
