@@ -1,5 +1,6 @@
 ///
 ///  Copyright (C) 2006-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -71,6 +72,11 @@ public:
   {
     m_matchParens = match;
   }
+  void SetInsertAns(bool insertAns)
+  {
+    m_insertAns = insertAns;
+  }
+  bool FindMatchingQuotes();
   void FindMatchingParens();
   wxString GetLineString(int line, int start = 0, int end = -1);
   bool IsDirty()
@@ -144,6 +150,7 @@ private:
   int m_charHeight;
   bool m_matchParens;
   int m_paren1, m_paren2;
+  bool m_insertAns;
   bool m_isDirty;
   bool m_displayCaret;
   bool m_hasFocus;
