@@ -1,6 +1,7 @@
 ///
 ///  Copyright (C) 2008-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///            (C) 2008-2009 Ziga Lenarcic <zigalenarcic@users.sourceforge.net>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -32,6 +33,7 @@ GroupCell::GroupCell(int groupType, wxString initString) : MathCell()
   m_input = NULL;
   m_output = NULL;
   m_hiddenTree = NULL;
+  m_hiddenTreeParent = NULL;
   m_outputRect.x = -1;
   m_outputRect.y = -1;
   m_outputRect.width = 0;
@@ -58,9 +60,12 @@ GroupCell::GroupCell(int groupType, wxString initString) : MathCell()
   }
 
   bool match = true;
+  bool insertAns = true;
   wxConfig::Get()->Read(wxT("matchParens"), &match);
+  wxConfig::Get()->Read(wxT("insertAns"), &insertAns);
   EditorCell *editor = new EditorCell();
   editor->SetMatchParens(match);
+  editor->SetInsertAns(insertAns);
 
   switch (groupType) {
     case GC_TYPE_CODE:
@@ -605,6 +610,7 @@ wxString GroupCell::PrepareForTeX(wxString str)
   str1.Replace(wxT("\\"), wxT("\\verb|\\|"));
   str1.Replace(wxT("_"), wxT("\\_"));
   str1.Replace(wxT("%"), wxT("\\%"));
+  str1.Replace(wxT("$"), wxT("\\$"));
   str1.Replace(wxT("{"), wxT("\\{"));
   str1.Replace(wxT("}"), wxT("\\}"));
   str1.Replace(wxT("^"), wxT("\\verb|^|"));
@@ -1107,17 +1113,45 @@ bool GroupCell::HideTree(GroupCell *tree)
   if (m_hiddenTree)
     return false;
   m_hiddenTree = tree;
+  m_hiddenTree->SetHiddenTreeParent(this);
   return true;
-
 }
 
 GroupCell *GroupCell::UnhideTree()
 {
   GroupCell *tree = m_hiddenTree;
+  m_hiddenTree->SetHiddenTreeParent(m_hiddenTreeParent);
   m_hiddenTree = NULL;
   return tree;
 }
 
+/**
+ * Unfold a tree from the bottom up, when a hidden cell needs to be seen.
+ *
+ * @return true if any cells were unfolded.
+ */
+bool GroupCell::RevealHidden()
+{
+  if (!m_hiddenTreeParent)
+    return false;
+  m_hiddenTreeParent->RevealHidden();
+  m_hiddenTreeParent->Unfold();
+  return true;
+}
+
+/**
+ * For every cell in this GroupCell, set m_hiddenTreeParent to parent.
+ * This way, the field can be used to traverse up the tree no matter which
+ * child we are on. In other words, every child knows its parent node.
+ */
+void GroupCell::SetHiddenTreeParent(GroupCell* parent) {
+  GroupCell* cell = this;
+  while (cell) {
+    cell->m_hiddenTreeParent = parent;
+    cell = dynamic_cast<GroupCell*>(cell->m_next);
+  }
+}
+
 GroupCell *GroupCell::Fold() {
   if (!IsFoldable() || m_hiddenTree) // already folded?? shouldn't happen
     return NULL;
@@ -1150,6 +1184,7 @@ GroupCell *GroupCell::Fold() {
   start->m_previous = start->m_previousToDraw = NULL;
   end->m_next = end->m_nextToDraw = NULL;
   m_hiddenTree = start; // save the torn out tree into m_hiddenTree
+  m_hiddenTree->SetHiddenTreeParent(this);
   return this;
 }
 
@@ -1173,6 +1208,7 @@ GroupCell *GroupCell::Unfold() {
   if (next)
     next->m_previous = next->m_previousToDraw = tmp;
 
+  m_hiddenTree->SetHiddenTreeParent(m_hiddenTreeParent);
   m_hiddenTree = NULL;
   return dynamic_cast<GroupCell*>(tmp);
 }
