@@ -1,5 +1,6 @@
 ///
 ///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///            (C) 2012-2013 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -164,6 +165,7 @@ public:
   void SetWorkingGroup(GroupCell *group);
   bool IsSelectionInWorking();
   void SetActiveCell(EditorCell *cell, bool callRefresh = true);
+  void SetDefaultHCaret();
   void SetHCaret(MathCell *where, bool callRefresh = true); // call with false, when manually refreshing
   GroupCell *GetHCaret();
   void OpenHCaret(wxString txt = wxEmptyString, int type = GC_TYPE_CODE);
@@ -178,12 +180,14 @@ public:
   void RemoveAllOutput();
   // methods related to evaluation queue
   void AddDocumentToEvaluationQueue();
+  void AddEntireDocumentToEvaluationQueue();
   void AddSelectionToEvaluationQueue();
   void AddCellToEvaluationQueue(GroupCell* gc);
   void ClearEvaluationQueue();
   EvaluationQueue* m_evaluationQueue;
   // methods for folding
   GroupCell *UpdateMLast();
+  void FoldOccurred();
   GroupCell *ToggleFold(GroupCell *which);
   GroupCell *ToggleFoldAll(GroupCell *which);
   void FoldAll();
@@ -199,6 +203,7 @@ public:
   void Replace(wxString oldString, wxString newString);
   int ReplaceAll(wxString oldString, wxString newString);
   wxString GetInputAboveCaret();
+  wxString GetOutputAboveCaret();
   bool LoadSymbols(wxString file) { return m_autocomplete.LoadSymbols(file); }
   bool Autocomplete(bool templates = false);
   void AddSymbol(wxString fun, bool templ = false) { m_autocomplete.AddSymbol(fun, templ); }
