@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -49,10 +49,12 @@ protected:
   MathCell *m_innerCell, *m_open, *m_close;
   MathCell *m_last1;
   bool m_print;
-#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+#if defined __WXMSW__
   int m_charWidth, m_charHeight;
   int m_charWidth1, m_charHeight1;
 #endif
+  int m_parenFontSize, m_signTop, m_signSize, m_signWidth;
+  int m_bigParenType;
 };
 
 #endif //_PARENCELL_H_
