@@ -1,5 +1,6 @@
 ///
 ///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///            (C) 2013 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -116,6 +117,7 @@ protected:
   void OnReplace(wxFindDialogEvent& event);
   void OnReplaceAll(wxFindDialogEvent& event);
 
+  void SanitizeSocketBuffer(char *buffer, int length);  // fix early nulls
   void ServerEvent(wxSocketEvent& event);          // server event: maxima connection
   void ClientEvent(wxSocketEvent& event);          // client event: maxima input/output
 
@@ -139,6 +141,7 @@ protected:
   void PrintMenu(wxCommandEvent& event);
 #endif
 
+  wxString ExtractFirstExpression(wxString entry);
   wxString GetDefaultEntry();
   bool StartServer();                              // starts the server
   bool StartMaxima();                              // starts maxima (uses getCommand)
