@@ -1,6 +1,7 @@
 ///
 ///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-///                2011-2011 cw.ahbong <cwahbong@users.sourceforge.net>
+///            (C) 2011-2011 cw.ahbong <cwahbong@users.sourceforge.net>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -289,13 +290,17 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2 = new wxMenu;
   wxglade_tmp_menu_2->Append(menu_evaluate, _("Evaluate Cell(s)"),
                              _("Evaluate active or selected cell(s)"), wxITEM_NORMAL);
-  wxglade_tmp_menu_2->Append(menu_evaluate_all, _("Evaluate All Cells\tCtrl-R"),
+  wxglade_tmp_menu_2->Append(menu_evaluate_all_visible, _("Evaluate All Visible Cells\tCtrl-R"),
+                               _("Evaluate all visible cells in the document"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_evaluate_all, _("Evaluate All Cells\tCtrl-Shift-R"),
                                _("Evaluate all cells in the document"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->Append(menu_remove_output, _("Remove All Output"),
                             _("Remove output from input cells"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
   wxglade_tmp_menu_2->Append(menu_insert_previous_input, _("Copy Previous Input\tCtrl-I"),
-                                  _("Create a new cell with previous input"), wxITEM_NORMAL);
+                             _("Create a new cell with previous input"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_insert_previous_output, _("Copy Previous Output\tCtrl-U"),
+                             _("Create a new cell with previous output"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->Append(menu_autocomplete, _("Complete Word\tCtrl-K"),
                              _("Complete word"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->Append(menu_autocomplete_templates, _("Show Template\tCtrl-Shift-K"),
@@ -316,6 +321,11 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_insert_image, _("Insert Image..."),
                              _("Insert image"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
+  wxglade_tmp_menu_2->Append(menu_fold_all_cells, _("Fold All\tCtrl-Alt-["),
+                              _("Fold all sections"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_unfold_all_cells, _("Unfold All\tCtrl-Alt-]"),
+                              _("Unfold all folded sections"), wxITEM_NORMAL);
+  wxglade_tmp_menu_2->AppendSeparator();
   wxglade_tmp_menu_2->Append(menu_history_previous, _("Previous Command\tAlt-Up"),
                              _("Recall previous command from history"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->Append(menu_history_next, _("Next Command\tAlt-Down"),
