@@ -1,5 +1,6 @@
 ///
 ///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///            (C) 2012 Doug Ilijev <doug.ilijev@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -155,6 +156,7 @@ enum {
   menu_build_info,
   menu_bug_report,
   menu_add_path,
+  menu_evaluate_all_visible,
   menu_evaluate_all,
   menu_show_tip,
   menu_copy_from_console,
@@ -205,8 +207,11 @@ enum {
   menu_add_section,
   menu_add_title,
   menu_add_pagebreak,
+  menu_fold_all_cells,
+  menu_unfold_all_cells,
   menu_insert_input,
   menu_insert_previous_input,
+  menu_insert_previous_output,
   menu_autocomplete,
   menu_autocomplete_templates,
   menu_cut,
